@@ -22,7 +22,7 @@ from pathlib import Path
 from .datadir import DataDir, create_datadir
 from .metadata import MetaData
 from .numtype import arrayinfotodtype, arraynumtypeinfo, numtypesdescr
-from .readcodearray import readcode
+from .readcodearray import readcode, readcodefunc
 from .utils import fit_frames, wrap, check_accessmode, product, tempdirfile
 from ._version import get_versions
 
@@ -632,6 +632,36 @@ class Array:
                        accessmode=accessmode, metadata=metadata,
                        chunklen=chunklen, overwrite=overwrite)
 
+    def readcode(self, language):
+        """Generate code to read the array in a different language.
+
+        Note that this does not include reading the metadata, which is just
+        based on a text file in JSON format.
+        
+        Parameter
+        ---------
+        language: str
+            One of the languages that are supported. Choose from:
+            'darr', 'idl', 'julia_ver0', 'julia_ver1', 'mathematica',
+            'matlab', 'maple', 'numpy', 'numpymemmap', 'R'.
+        Example
+        -------
+        >>> import darr
+        >>> a = darr.asarray('test.darr', [[1,2,3],[4,5,6]])
+        >>> print(a.readcode('matlab'))
+        fileid = fopen('arrayvalues.bin');
+        a = fread(fileid, [3, 2], '*int32', 'ieee-le');
+        fclose(fileid);
+
+        """
+        if language not in readcodefunc.keys():
+            raise ValueError(f'Language "{language}" not supported, choose '
+                             f'from {readcodefunc.keys()}')
+        d = self._arrayinfo
+        return readcodefunc[language](numtype=d['numtype'],
+                                      shape=d['shape'],
+                                      endianness=d['byteorder'])
+
 
 def _fillgenerator(shape, dtype='float64', fill=0., fillfunc=None,
                    chunklen=None):
@@ -937,6 +967,67 @@ def create_array(path, shape, dtype='float64', fill=None, fillfunc=None,
 def create_temparray(shape, dtype='float64', fill=None, fillfunc=None,
                      accessmode='r+', chunklen=None, metadata=None,
                      report=True, overwrite=False):
+    """Creates a temporary darr array that is deleted automatically after
+    use.
+
+    Parameters
+    ----------
+    shape : int ot sequence of ints
+        Shape of the `darr`.
+    dtype : dtype, optional
+        The type of the `darr`. Default is 'float64'
+    fill : number, optional
+        The value used to fill the array with. Default is `None`, which will
+        lead to the array being filled with zeros.
+    fillfunc : function, optional
+        A function that generates the fill values, potentially on the basis of
+        the index numbers of the first axis of the array. This function should
+        only have one argument, which will be automatically provided during
+        filling and which represents the index numbers along the first axis for
+        all dimensions (see example below). If `fillfunc` is provided, `fill`
+        should be `None`.  And vice versa. Default is None.
+    accessmode : <`r`, `r+`>, optional
+        File access mode of the darr data. `r` means real-only, `r+`
+        means read-write, i.e. values can be changed. Default `r`.
+    chunklen: <int, None>
+        The length of chunks (along first axis) that are written during
+        creation. If None, it is chosen so that chunks are 10 Mb in total size.
+    metadata: {None, dict}
+        Dictionary with metadata to be saved in a separate JSON file. Default
+        None
+    report: bool
+        Prints info on the path of the array when it is created, and when it
+        is deleted. This is handy in case something goes wrong, and you need
+        to delete the array by hand.
+    overwrite: <True, False>, optional
+        Overwrites existing darr data if it exists. Note that a darr
+        paths is a directory. If that directory contains additional files,
+        these will not be removed and an OSError is raised.
+        Default is `False`.
+
+    Returns
+    -------
+    Array
+        A Darr `array` instance.
+
+    See Also
+    --------
+    create_array : create a non-temporary darr array.
+
+    Examples
+    --------
+    >>> import darr
+    >>> import numpy as np
+    >>> with darr.create_temparray(shape=(5,2)) as a:
+        a[:] = 3
+        b = np.product(a)
+    created temporary directory C://Users/Gabriel/AppData/Local/Temp/tmpc8z0alnh
+    removed temporary directory C://Users/Gabriel/AppData/Local/Temp/tmpc8z0alnh
+
+    >>> b
+        59049.0
+
+    """
     with tempdirfile(report=report) as path:
         yield create_array(path=path, shape=shape, dtype=dtype, fill=fill,
                            fillfunc=fillfunc, accessmode=accessmode,
@@ -1095,11 +1186,12 @@ def numtypedescriptiontxt(da):
              "open and simple format and that is easy to access in most "\
              "analysis environments. In Python, you can use the Darr "\
              "library (https://pypi.org/project/darr/), which was used to "\
-             "create the data. If Darr is not available, it is "\
-             "straightforward to access the data using the information "\
-             "below, which includes code for a number of popular platforms.")  + "\n\n\n"
+             "create the data. Alternatively, to access the data directly in "
+             "Python or other environments, use the information below, "\
+             "which includes code for a number of popular platforms.")  + "\n\n\n"
     s+= f"Data format\n===========\n\n"
-    s += wrap("The file 'arrayvalues.bin' contains a numeric array in the "
+    s += wrap("The file 'arrayvalues.bin' contains the raw binary values of "
+              "the numeric array, without header information, in the "
               "following format:") + "\n\n"
     s +=f"  Numeric type: {typedescr}\n" \
         f"  Byte order: {endianness} ({endiannessdescr})\n"
@@ -1108,12 +1200,9 @@ def numtypedescriptiontxt(da):
     else:
         s += f"  Array dimensions: {shape}\n"
     s += f"  Array order layout:  {arrayorder} ({arrayorderdescr})\n\n"
-    s += wrap("The file only contains the raw binary values, without header "
-              "information.") + "\n\n"
-    s += wrap("Format details are also stored in json format in the separate "
-              "UTF-8 text file, 'arraydescription.json' to facilitate "
-              "automatic reading by a program.") + "\n\n"
+    s += wrap("These details are also stored in JSON format in the separate "
+              "UTF-8 text file, 'arraydescription.json'.") + "\n\n"
     if len(da.metadata) > 0:
-        s += wrap("The file 'metadata.json' contains metadata in json UTF-8 "\
+        s += wrap("The file 'metadata.json' contains metadata in JSON UTF-8 "\
                   "text format.") + "\n\n\n"
     return s
