@@ -9,7 +9,7 @@ from .array import Array, MetaData, asarray, \
     truncate_array
 from .datadir import DataDir, create_datadir
 from .metadata import MetaData
-from .readcoderaggedarray import readcode
+from .readcoderaggedarray import readcode, readcodefunc
 from .utils import wrap
 
 __all__ = ['RaggedArray', 'asraggedarray', 'create_raggedarray',
@@ -204,6 +204,41 @@ class RaggedArray:
         self._update_arraydescr(len=len(self._indices),
                                 size=self._values.size)
 
+    def readcode(self, language):
+        """Generate code to read the array in a different language.
+
+        Note that this does not include reading the metadata, which is just
+        based on a text file in JSON format.
+
+        Parameter
+        ---------
+        language: str
+            One of the languages that are supported. Choose from:
+            'matlab', 'numpymemmap', 'R'.
+
+        Example
+        -------
+        >>> import darr
+        >>> a = darr.asraggedarray('test.darr', [[1],[2,3],[4,5,6],[7,8,9,10]], overwrite=True)
+        >>> print(a.readcode('matlab'))
+        fileid = fopen('indices/arrayvalues.bin');
+        i = fread(fileid, [2, 4], '*int64', 'ieee-le');
+        fclose(fileid);
+        fileid = fopen('values/arrayvalues.bin');
+        v = fread(fileid, 10, '*int32', 'ieee-le');
+        fclose(fileid);
+        % example to read third subarray
+        startindex = i(1,3) + 1;  % matlab starts counting from 1
+        endindex = i(2,3);  % matlab has inclusive end index
+        a = v(startindex:endindex);
+
+        """
+        if language not in readcodefunc.keys():
+            raise ValueError(f'Language "{language}" not supported, choose '
+                             f'from {readcodefunc.keys()}')
+        d = self._arrayinfo
+        return readcodefunc[language](self)
+
 
 # FIXME empty arrayiterable
 def asraggedarray(path, arrayiterable, dtype=None, metadata=None,
@@ -273,15 +308,18 @@ def create_raggedarray(path, atom=(), dtype='float64', metadata=None,
     ra._update_arraydescr(len=0, size=0)
     return RaggedArray(ra.path, accessmode=accessmode)
 
-
+# TODO, simplify explanation if subarrays are 1-dimensional
+# TODO add readcode for more languages
 readmetxt = wrap('Disk-based storage of a ragged array') + '\n' + \
             wrap('====================================') + '\n\n' + \
-            wrap('This directory is a data store for a numeric ragged array, '
-                 'which is a sequence of arrays in which one dimension varies '
-                 'in length. On disk, these arrays are concatenated along '
-                 'their variable dimension. The easiest way to access the '
-                 'data is to use the Darr library '
-                 '(https://pypi.org/project/darr/) in Python, as follows:') \
+            wrap('This directory is a data store for a numeric ragged array. '
+                 'A ragged array (also called a jagged array) is a sequence '
+                 'of arrays that may vary in length in their first '\
+                 'dimension only. On disk, these arrays are concatenated '\
+                 'along their variable dimension. The easiest way to '\
+                 'access the data is to use the Darr library '\
+                 '(https://pypi.org/project/darr/) in Python, as '\
+                 'follows:') \
             + '\n\n' \
             + '>>> import darr\n' \
             + ">>> a = darr.RaggedArray('path_to_array_dir')\n\n" + \
@@ -289,8 +327,8 @@ readmetxt = wrap('Disk-based storage of a ragged array') + '\n' + \
               "directory, which is the one that also contains this README.")\
                + "\n\n" + \
             wrap('If Darr is not available, the data can also be read in '\
-                 'other environments, with more effort, using the '\
-                 'description and example code below.') + '\n\n\n' \
+                 'other environments, with a little more effort, using the '\
+                 'description or example code below.') + '\n\n\n' \
             + 'Description of data storage\n' \
             + '---------------------------\n' + \
             wrap('There are two subdirectories, each containing an array '
